*==============================================================================
* Program:				DROPMAIL.PRG
* Purpose:				Process email dropped on an OLE control
* Author:				Ted Roche
* Copyright:			(c) 2002 
* Last revision:		05/27/02
* Parameters:			lvDropValue (ignored)
* Returns:				loReturn - parameter object
* .....................          - cBody contains entire email in journal form
* .....................          - cSubject is subject in journal form
* .....................          - aAttachment array, one row per attachment
* .....................          -- column 1 is original filename
* .....................          -- column 2 is metafilename where saved (not implemented)
* Environment in:		
* Environment out:		
*==============================================================================

LPARAMETERS lvDropValue

* Declare variables

LOCAL loOutlook as Outlook.Application, ;
      loSelection as Outlook.Selection, ;
      loItem as Outlook.MailItem, ;
      loAttachments as Outlook.Attachments, ;
      loAttachment as Outlook.Attachment 

LOCAL lcMessage as String, ;
      lcSubject as String, ;
      lcBody as String, ;
      loParameter as cusParameter, ;
      liRow as Integer, ;
      liAttCount as Integer, ;
      lcPath as String, ;
      lcMetaFileName as String
      

STORE SPACE(0) TO lcMessage, lcSubject, lcBody

*********************************************************
* Create return object
*********************************************************
loParameter = CREATEOBJECT("cusParameter")
IF VARTYPE(loParameter) # "O"
  ERROR "Cannot create parameter object")
ENDIF


*********************************************************
* Outlook's Current UI has dragged items selected
*********************************************************

loOutlook = CREATEOBJECT("Outlook.Application")
loSelection = loOutlook.ActiveExplorer.Selection

*********************************************************
* Iterate through selected objects
*********************************************************

FOR m.i = 1 TO loSelection.Count

  * Check the messageclass so we can assume the properties are available
  loItem = loSelection.Item(m.i)
  IF TYPE("loItem.MessageClass") = "C" AND loItem.MessageClass = "IPM.Note"
    *********************************************************
    * Append message fields only if they do not already appear 
    * in the text
    *********************************************************
    lcSubject = lcSubject + ;
                IIF(loItem.Subject $ lcSubject, ;
                    SPACE(0), ;  && subject already in string
                    IIF(EMPTY(lcSubject),SPACE(1), "; ") + loItem.Subject)  && or add it

    *********************************************************
    * Message is in plain text format
    *********************************************************

    lcMessage = lcMessage + CHR(13) + CHR(10) + ;
                "To: " + loItem.To + CHR(13) + CHR(10) + ;
                "From: " + loItem.SenderName + CHR(13) + CHR(10) + ;
                "CC:" + loItem.CC + CHR(13) + CHR(10) + ;                
                "Subject: " + loItem.Subject + CHR(13) + CHR(10) + ;
                "Body: " + loItem.Body + CHR(13) + CHR(10) + ;
                REPLICATE("=",30) + CHR(13) + CHR(10)
     
     * Add the strings to the Parameter Object
     loParameter.cSubject = lcSubject
     loParameter.cBody = lcMessage
     
     *********************************************************
     * Add any attachments to the parameter object
     *********************************************************
     IF loItem.Attachments.Count > 0
       loAttachments = loItem.Attachments
       FOR liAttCount = 1 TO loAttachments.Count
         loAttachment = loAttachments.Item(liAttCount)
         *********************************************************
         * Save each attachment to disk
         *********************************************************
         * 
         * loAttachment.SaveAsFile(lcPath + lcMetaFileName)
         *********************************************************
         liRow = loParameter.iAttachmentCount + 1 
         loParameter.iAttachmentCount = liRow
         DIMENSION loParameter.aAttachments[liRow,2]
         loParameter.aAttachments[liRow,1] = loAttachment.DisplayName
         loParameter.aAttachments[liRow,2] = "Fake data"
         * loParameter.aAttachments[liRow,2] = && path where saved
       NEXT && attachment count
     ENDIF && there are attachments
     
  ENDIF  && "IPM.Note"
ENDFOR

* MESSAGEBOX(lcMessage)  && debugging

RETURN loParameter

DEFINE CLASS cusParameter as Custom
  cSubject = SPACE(1)
  cBody = SPACE(1)
  iAttachmentCount = 0
  DIMENSION aAttachments[1,2]
  
ENDDEFINE

